.textHead{
  text-shadow: 2px 2px @theme_bg_color;
  color: @theme_text_color;
}
.boxInfoMessError{
  background-color: #ea9999;
}
.boxInfoMessOK{
  background-color: #f3f0ac;
}
.bannerbackground {
  background-color: #404040;
}
.view_app {
  background-color: @theme_bg_color;
}
.view_app.view.cell:selected {
  background-color:@theme_selected_bg_color;
	color:@theme_selected_text_color;
	transition: 10ms ease-out;
  border-radius: 3px;
}
#GnomeIcon{
  border-style:solid;
  border-bottom-width: 1px;
  border-image: linear-gradient(90deg, alpha(@theme_text_color,0.4) 55%, alpha(@theme_bg_color, 0) 100%);
  border-image-slice: 1;
}

#SepIcon{
  background-color: alpha(@theme_text_color, 0.6);
}

#iconlabel {
  font-size:14px;
  font-weight: bold;
  
}
.roundborder * {
  border-width:0px;
  border-radius:5px;
}
.noborder {
  border: none;
}
.menu:hover {	
    border-color:alpha(@theme_text_color, 0.01);
}
.menu {	
    border-color:alpha(@theme_text_color, 0.01);
}
.menu:hover >* {
  border-color:alpha(@theme_text_color, 0.01);
}
.menuitembottom{
  margin-top:0px;
  margin-bottom:3px;
}
.menuitemmiddle{
  margin-top:0px;
  margin-bottom:0px;
}

.menuitemtop{
  margin-bottom:0px;
}
.menuitemtop *{
  margin:2px 2px 0 2px;
  padding: 5px 10px 3px 5px;
}
.menuitemmiddle *{
  margin:0 2px 0 2px;
  padding: 3px 10px 3px 5px;
}
.menuitembottom *{
  margin:0 2px 2px 2px;
  padding: 3px 10px 5px 5px;
}
.menuitemtop:hover {
  background:@theme_bg_color;
  border-color:inherit;
  border-left-width:inherit;
  border-right-width:inherit;
}
.menuitemmiddle:hover {
  background:@theme_bg_color;
  border-color:inherit;
  border-left-width:inherit;
  border-right-width:inherit;
}
.menuitembottom:hover {
  background:@theme_bg_color;
  border-color:inherit;
  border-left-width:inherit;
  border-right-width:inherit;
  
}
.menuitemtop:hover* {
  margin:2px 2px 0 2px;
  padding: 5px 10px 3px 5px;
  background:@theme_selected_bg_color;
  border-radius:2px;
}
.menuitemmiddle:hover* {
  margin:0 2px 0 2px;
  padding: 3px 10px 3px 5px;
  background:@theme_selected_bg_color;
  border-radius:2px;
}
.menuitembottom:hover* {
  margin:0 2px 2px 2px;
  padding: 3px 10px 5px 5px;
  background:@theme_selected_bg_color;
  border-radius:2px;
}

.workingbg, #workingbg {
  background-color:@theme_base_color;
}
.workingbg.view.cell:selected {
  background-color:@theme_selected_bg_color;
}
.workingbg.view.cell:hover {
  background-color:darker(@theme_selected_bg_color);
  color:@theme_selected_text_color;
  border-radius:3px;
}
.bkim {
  transition: 200ms ease-out;
      background-image: none;
}
.noborder{
border:none;
}

.bkim{
opacity:0.99;
border:none;
}

.bkim_no_plug{
background-color: transparent;
opacity:0.99;
}


.thin{
  margin:0px;
  padding: 0px;
}
.nobg{
  background: none;
}
.addbg * {
  background-color: @theme_bg_color;
}